##  Step 4: Define Object Type
Select which Jira Service Management object type maps to the selected fact sheet type:
  1. The interface displays your Jira Service Management schema structure. Browse the schema hierarchy.
  2. Select the object type that corresponds to the fact sheet type.
  3. Choose Next.
